OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "ダークテーマ",
    "Enable dark theme" : "ダークテーマを有効にする",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "ダークテーマは目の負担になりにくいです。このテーマは開発中のためバグを見つけたら報告してください。",
    "High contrast mode" : "ハイ・コントラストモード",
    "Enable high contrast mode" : "ハイ・コントラストモードを有効にする。",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "操作をわかりやすくするためのハイ・コントラストモード。\n見た目の美しさは低下しますが、明確さが向上します。",
    "Dyslexia font" : "Dyslexia フォント",
    "Enable dyslexia font" : "Dyslexia フォントを有効にする",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexicは、ディスレクシアによって引き起こされる一般的な読み間違いの一部を軽減するためにデザインされた、無料で利用できる書体/フォントです。",
    "Accessibility" : "アクセシビリティ",
    "Accessibility options for nextcloud" : "nextcloudのアクセシビリティオプション",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "あなたのNextcloudの利用を簡単にするための複数のユーザー補助のオプションを提供します。",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "問題がある場合は、お気軽に{issuetracker}issue tracker {linkend}に報告してください。 手伝って頂ける方は、{designteam}デザインチーム{linkend}にご参加ください。",
    "Enable" : "有効にする"
},
"nplurals=1; plural=0;");
